/******************************************************************************
//                                                                           //
//  Project: Software Interface for HV-AMP-CTRL Devices                      //
//                                                                           //
//  CGC Instruments, (c) 2010-2015, Version 1-00. All rights reserved.       //
//                                                                           //
//  Definition for COM-RFG DLL Routines                                      //
//                                                                           //
******************************************************************************/

#ifndef __COM_RFG_H__
#define __COM_RFG_H__


#ifdef __cplusplus
extern "C" {
#endif

#define COM_RFG_MAX_PORT 8 /* Maximum PortNumber */

/*
	The communication channel must be opened before the first usage.

	If necessary, the channel may be closed and reopened again.
	The channel is closed automatically at the end of the program, the main program does not need to take care about it.

	The return values of the routines are the following defines COM_RFG_ERR_XXX
		 0: routine finished without any error
		<0: errors COM_RFG_ERR_XXX

	The last error code can be obtained by calling COM_RFG_State.
	The routine COM_RFG_ErrorMessage returns a pointer to a zero-terminated character string or NULL in case of a failure.

	If a communication error occurred, the error code can be red again by COM_RFG_IO_State,
	The routine COM_RFG_IO_ErrorMessage provides the corresponding error message.
*/

#define COM_RFG_ERR_OPEN             -2 /* Error opening the port                          */
#define COM_RFG_ERR_CLOSE            -3 /* Error closing the port                          */
#define COM_RFG_ERR_PURGE            -4 /* Error purging the port                          */
#define COM_RFG_ERR_CONTROL          -5 /* Error setting the port control lines            */
#define COM_RFG_ERR_STATUS           -6 /* Error reading the port status lines             */
#define COM_RFG_ERR_COMMAND_SEND     -7 /* Error sending command                           */
#define COM_RFG_ERR_DATA_SEND        -8 /* Error sending data                              */
#define COM_RFG_ERR_TERM_SEND        -9 /* Error sending termination character             */
#define COM_RFG_ERR_COMMAND_RECEIVE -10 /* Error receiving command                         */
#define COM_RFG_ERR_DATA_RECEIVE    -11 /* Error receiving data                            */
#define COM_RFG_ERR_TERM_RECEIVE    -12 /* Error receiving termination character           */
#define COM_RFG_ERR_COMMAND_WRONG   -13 /* Wrong command received                          */
#define COM_RFG_ERR_ARGUMENT_WRONG  -14 /* Wrong argument received                         */
#define COM_RFG_ERR_ARGUMENT        -15 /* Wrong argument passed to the function           */

#define COM_RFG_ERR_NOT_CONNECTED  -100 /* Device not connected                            */
#define COM_RFG_ERR_NOT_READY      -101 /* Device not ready                                */
#define COM_RFG_ERR_READY          -102 /* Device state could not be set to not ready      */

#define COM_RFG_ERR_PORT_RANGE     -200 /* PortNumber out of range                         */
#define COM_RFG_ERR_MEMORY_ALLOC   -300 /* Memory for the port data could not be allocated */

#define COM_RFG_ERR_DEBUG_OPEN     -400 /* Error opening the file for debugging output     */
#define COM_RFG_ERR_DEBUG_CLOSE    -401 /* Error closing the file for debugging output     */

/* Communication */
int FAR _export pascal COM_RFG_Open  (WORD PortNumber, BYTE COMNumber); /* Open the port  */
int FAR _export pascal COM_RFG_Close (WORD PortNumber);                 /* Close the port */

int FAR _export pascal COM_RFG_Purge        (WORD PortNumber);               /* Clear data buffers for the port                                              */
int FAR _export pascal COM_RFG_Buffer_State (WORD PortNumber, BOOL & Empty); /* Return true if the input data buffer of the device is empty                  */
int FAR _export pascal COM_RFG_Device_Purge (WORD PortNumber, BOOL & Empty); /* Clear output data buffer of the device, return value as COM_RFG_Buffer_State */

/* RFG control */
int FAR _export pascal COM_RFG_Get_Amplitude (WORD PortNumber, double & Amplitude); /* Get amplitude                               */
int FAR _export pascal COM_RFG_Set_Amplitude (WORD PortNumber, double & Amplitude); /* Set amplitude and return the set value back */
int FAR _export pascal COM_RFG_Get_Enable    (WORD PortNumber, BOOL   & Enabled  ); /* Get the enable state                               */
int FAR _export pascal COM_RFG_Set_Enable    (WORD PortNumber, BOOL   & Enabled  ); /* Set the enable state and return the set value back */

/* Monitoring */
int FAR _export pascal COM_RFG_Get_HousekeepingData (WORD PortNumber, double & Voltage12V, double & Voltage5V,  double & Voltage3V,                                                    double & Temperature    ); /* Get housekeeping data */
int FAR _export pascal COM_RFG_Get_RFGData          (WORD PortNumber, double & Amplitude1, double & Amplitude2, double & VoltageDrain, long & Frequency, double & TemperatureHeatsink, double & TemperatureCoil); /* Get RFG data          */
int FAR _export pascal COM_RFG_Get_PowerData        (WORD PortNumber, double & Voltage,    double & Current,                                                                           double & Temperature    ); /* Get power supply data */
int FAR _export pascal COM_RFG_Get_InterlockState   (WORD PortNumber, BOOL & Closed);                                                                                                                             /* Get interlock state   */

/* Keypad & encoder */
#define COM_RFG_KEY_NO      0x00 /* no key pressed */
#define COM_RFG_KEY_LEFT    0x01 /* key left       */
#define COM_RFG_KEY_RIGHT   0x08 /* key right      */
#define COM_RFG_KEY_UP      0x10 /* key up         */
#define COM_RFG_KEY_DOWN    0x02 /* key bottom     */
#define COM_RFG_KEY_MIDDLE  0x04 /* key middle     */
int FAR _export pascal COM_RFG_SimulateKeypad (WORD PortNumber, BYTE KeyCode); /* Simulate pressing of the keypad, KeyCode may be any combination of the constants COM_RFG_KEY_XXX */

#define COM_RFG_ENC_SPEED0  0x01 /* middle rotation speed                                                                */
#define COM_RFG_ENC_SPEED1  0x02 /* high rotation speed                                                                  */
#define COM_RFG_ENC_ACCEL   0x04 /* accelerated rotation speed, i.e. emulate simultaneous pressing of the left arrow key */
#define COM_RFG_ENC_POSDIR  0x08 /* clockwise rotation                                                                   */
int FAR _export pascal COM_RFG_SimulateEncoder       (WORD PortNumber, BYTE EncCode); /* Simulate rotating of the encoder, EncCode may be any combination of the constants COM_RFG_ENC_XXX */
int FAR _export pascal COM_RFG_SimulateEncoderButton (WORD PortNumber);               /* Simulate pressing of the encoder button                                                           */

/* LCD */
#define COM_RFG_LCD_WIDTH_PIXEL  128
#define COM_RFG_LCD_HEIGHT_PIXEL  64
#define COM_RFG_LCD_CHAR_HEIGHT    8
#define COM_RFG_LCD_MEM_SIZE     (COM_RFG_LCD_WIDTH_PIXEL  * COM_RFG_LCD_HEIGHT_PIXEL / 8)
#define COM_RFG_LCD_HEIGHT       (COM_RFG_LCD_HEIGHT_PIXEL / COM_RFG_LCD_CHAR_HEIGHT)
int FAR _export pascal COM_RFG_ReadDisplay    (WORD PortNumber,           BYTE Buffer [COM_RFG_LCD_MEM_SIZE]   ); /* Read display memory data               */
int FAR _export pascal COM_RFG_ReadDisplayRow (WORD PortNumber, WORD Row, BYTE Buffer [COM_RFG_LCD_WIDTH_PIXEL]); /* Read character row from display memory */

/* General */
WORD FAR _export pascal COM_RFG_Version(); /* Get the COM-RFG software version */

int FAR _export pascal COM_RFG_GetHardwareCapability (WORD PortNumber, double & MinAmplitude, double & MaxAmplitude, double & MaxPSUVoltage); /* Get device hardware capabilities */

int FAR _export pascal COM_RFG_GetUptime (WORD PortNumber, DWORD & Seconds, WORD & Milliseconds); /* Get device uptime */

int FAR _export pascal COM_RFG_FW_Ver  (WORD PortNumber, WORD & Version);            /* Get the firmware version                                                          */
int FAR _export pascal COM_RFG_FW_Date (WORD PortNumber, char * FAR DateString);     /* Get the firmware date, the buffer DateString should be 16 bytes long              */
int FAR _export pascal COM_RFG_Prod_ID (WORD PortNumber, char * FAR Identification); /* Get the product identification, the buffer Identification should be 81 bytes long */
int FAR _export pascal COM_RFG_Prod_No (WORD PortNumber, DWORD & Number);            /* Get the product number                                                            */

int          FAR _export pascal COM_RFG_State           (WORD PortNumber); /* Get software interface state                                           */
const char * FAR _export pascal COM_RFG_ErrorMessage    (WORD PortNumber); /* Get the error message corresponding to the software interface state    */
int          FAR _export pascal COM_RFG_IO_State        (WORD PortNumber); /* Get serial port interface state                                        */
const char * FAR _export pascal COM_RFG_IO_ErrorMessage (WORD PortNumber); /* Get the error message corresponding to the serial port interface state */

int FAR _export pascal COM_RFG_OpenDebugFile  (WORD PortNumber, const char * FAR FileName); /* Open a text file for debugging output */
int FAR _export pascal COM_RFG_CloseDebugFile (WORD PortNumber);                            /* Close the file for debugging output   */


#ifdef __cplusplus
}
#endif


#endif//__COM_RFG_H__
